@@ -5,8 +5,8 @@
 import * as React from 'react';
 import { themeStyle } from '@joplin/lib/theme';
 import { Theme } from '@joplin/lib/themes/type';
-import { useState, useMemo, useCallback, useRef } from 'react';
-import { Text, Pressable, ViewStyle, StyleSheet, LayoutChangeEvent, LayoutRectangle, Animated, AccessibilityState, AccessibilityRole, TextStyle, GestureResponderEvent, Platform, Role } from 'react-native';
+import { useState, useMemo, useCallback, useRef, Ref } from 'react';
+import { Text, Pressable, ViewStyle, StyleSheet, LayoutChangeEvent, LayoutRectangle, Animated, AccessibilityState, AccessibilityRole, TextStyle, GestureResponderEvent, Platform, Role, StyleProp, View } from 'react-native';
 import { Menu, MenuOptions, MenuTrigger, renderers } from 'react-native-popup-menu';
 import Icon from './Icon';
 import AccessibleView from './accessibility/AccessibleView';
@@ -15,11 +15,13 @@ type ButtonClickListener = ()=> void;
 interface ButtonProps {
 	onPress: ButtonClickListener;
 
+	pressableRef?: Ref<View>;
+
 	// Accessibility label and text shown in a tooltip
 	description: string;
 
 	iconName: string;
-	iconStyle: TextStyle;
+	iconStyle: StyleProp<TextStyle>;
 
 	themeId: number;
 
@@ -87,6 +89,7 @@ const IconButton = (props: ButtonProps) => {
 
 	const button = (
 		<Pressable
+			ref={props.pressableRef}
 			onPress={props.onPress}
 			onLongPress={onLongPress}
 			onPressIn={onPressIn}
