@@ -1,10 +1,11 @@
 import { EditorState, Plugin, Transaction } from 'prosemirror-state';
-import { OnEventCallback } from '../../types';
+import { OnEventCallback, OnLocalize } from '../../types';
 import { RendererControl } from '../types';
 
 export interface EditorApi {
 	renderer: RendererControl;
 	onEvent: OnEventCallback;
+	localize: OnLocalize;
 }
 
 
@@ -29,6 +30,8 @@ const joplinEditorApiPlugin = new Plugin<EditorApi>({
 					throw new Error('Not initialized');
 				},
 			},
+			settings: null,
+			localize: input => input,
 		}),
 		apply: (tr, value) => {
 			const proposedValue = tr.getMeta(joplinEditorApiPlugin);
