@@ -1,6 +1,11 @@
 import { RenderResult } from '../../renderer/types';
 
-export type MarkupToHtml = (markup: string)=> Promise<RenderResult>;
+interface MarkupToHtmlOptions {
+	isFullPageRender: boolean;
+	forceMarkdown: boolean;
+}
+
+export type MarkupToHtml = (markup: string, options: MarkupToHtmlOptions)=> Promise<RenderResult>;
 export type HtmlToMarkup = (html: Node|DocumentFragment)=> string;
 
 export interface RendererControl {
